# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 5.0.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from empire_platform_api_public_client.models.update_default_nomination_request import UpdateDefaultNominationRequest  # noqa: E501

class TestUpdateDefaultNominationRequest(unittest.TestCase):
    """UpdateDefaultNominationRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UpdateDefaultNominationRequest:
        """Test UpdateDefaultNominationRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UpdateDefaultNominationRequest`
        """
        model = UpdateDefaultNominationRequest()  # noqa: E501
        if include_optional:
            return UpdateDefaultNominationRequest(
                delivery_period_start = 'Tue Jan 04 00:00:00 UTC 2022',
                delivery_period_end = 'Tue Jan 04 00:00:00 UTC 2022',
                mtus = [
                    empire_platform_api_public_client.models.default_nomination_mtu.DefaultNominationMtu(
                        mtu = '10:00', 
                        type = 'PERCENT_100', 
                        value = 56, )
                    ]
            )
        else:
            return UpdateDefaultNominationRequest(
                delivery_period_start = 'Tue Jan 04 00:00:00 UTC 2022',
                mtus = [
                    empire_platform_api_public_client.models.default_nomination_mtu.DefaultNominationMtu(
                        mtu = '10:00', 
                        type = 'PERCENT_100', 
                        value = 56, )
                    ],
        )
        """

    def testUpdateDefaultNominationRequest(self):
        """Test UpdateDefaultNominationRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 5.0.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from empire_platform_api_public_client.api.profile_api import ProfileApi  # noqa: E501


class TestProfileApi(unittest.TestCase):
    """ProfileApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ProfileApi()  # noqa: E501

    def tearDown(self) -> None:
        pass

    def test_create_api_key(self) -> None:
        """Test case for create_api_key

        """
        pass

    def test_delete_api_key(self) -> None:
        """Test case for delete_api_key

        """
        pass

    def test_get_api_keys(self) -> None:
        """Test case for get_api_keys

        """
        pass

    def test_get_preferences(self) -> None:
        """Test case for get_preferences

        """
        pass

    def test_get_profile(self) -> None:
        """Test case for get_profile

        """
        pass

    def test_get_profile_details(self) -> None:
        """Test case for get_profile_details

        """
        pass

    def test_get_zendesk_chat_token(self) -> None:
        """Test case for get_zendesk_chat_token

        """
        pass

    def test_update_preferences(self) -> None:
        """Test case for update_preferences

        """
        pass

    def test_update_profile_details(self) -> None:
        """Test case for update_profile_details

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 5.0.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class AllocatedAuctionSortBy(str, Enum):
    """
    AllocatedAuctionSortBy
    """

    """
    allowed enum values
    """
    BIDDING_PERIOD_START_ASC = 'BIDDING_PERIOD_START_ASC'
    BIDDING_PERIOD_START_DESC = 'BIDDING_PERIOD_START_DESC'
    BIDDING_PERIOD_END_ASC = 'BIDDING_PERIOD_END_ASC'
    BIDDING_PERIOD_END_DESC = 'BIDDING_PERIOD_END_DESC'
    AUCTION_TYPE_ASC = 'AUCTION_TYPE_ASC'
    AUCTION_TYPE_DESC = 'AUCTION_TYPE_DESC'
    DELIVERY_PERIOD_START_ASC = 'DELIVERY_PERIOD_START_ASC'
    DELIVERY_PERIOD_START_DESC = 'DELIVERY_PERIOD_START_DESC'
    DELIVERY_PERIOD_END_ASC = 'DELIVERY_PERIOD_END_ASC'
    DELIVERY_PERIOD_END_DESC = 'DELIVERY_PERIOD_END_DESC'
    BORDER_DIRECTION_ASC = 'BORDER_DIRECTION_ASC'
    BORDER_DIRECTION_DESC = 'BORDER_DIRECTION_DESC'
    MARGINAL_CLEARING_PRICE_ASC = 'MARGINAL_CLEARING_PRICE_ASC'
    MARGINAL_CLEARING_PRICE_DESC = 'MARGINAL_CLEARING_PRICE_DESC'

    @classmethod
    def from_json(cls, json_str: str) -> AllocatedAuctionSortBy:
        """Create an instance of AllocatedAuctionSortBy from a JSON string"""
        return AllocatedAuctionSortBy(json.loads(json_str))





# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 5.0.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictInt, conlist
from empire_platform_api_public_client.models.border_direction import BorderDirection
from empire_platform_api_public_client.models.transmission_rights_overview_mtus_values_timescales import TransmissionRightsOverviewMtusValuesTimescales

class TransmissionRightsOverviewMtusValues(BaseModel):
    """
    TransmissionRightsOverviewMtusValues
    """
    direction: BorderDirection = Field(...)
    timescales: conlist(TransmissionRightsOverviewMtusValuesTimescales) = Field(...)
    total: Optional[StrictInt] = Field(None, description="Capacity value in kilowatts (kW) - the required system precision allows for handling capacity values as integers")
    curtailed: Optional[StrictInt] = Field(None, description="Capacity value in kilowatts (kW) - the required system precision allows for handling capacity values as integers")
    remaining: Optional[StrictInt] = Field(None, description="Capacity value in kilowatts (kW) - the required system precision allows for handling capacity values as integers")
    __properties = ["direction", "timescales", "total", "curtailed", "remaining"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> TransmissionRightsOverviewMtusValues:
        """Create an instance of TransmissionRightsOverviewMtusValues from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in timescales (list)
        _items = []
        if self.timescales:
            for _item in self.timescales:
                if _item:
                    _items.append(_item.to_dict())
            _dict['timescales'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> TransmissionRightsOverviewMtusValues:
        """Create an instance of TransmissionRightsOverviewMtusValues from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return TransmissionRightsOverviewMtusValues.parse_obj(obj)

        _obj = TransmissionRightsOverviewMtusValues.parse_obj({
            "direction": obj.get("direction"),
            "timescales": [TransmissionRightsOverviewMtusValuesTimescales.from_dict(_item) for _item in obj.get("timescales")] if obj.get("timescales") is not None else None,
            "total": obj.get("total"),
            "curtailed": obj.get("curtailed"),
            "remaining": obj.get("remaining")
        })
        return _obj





# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 5.0.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from empire_platform_api_public_client.models.participant_dashboard_transmission_rights_and_nominations_graph_data import ParticipantDashboardTransmissionRightsAndNominationsGraphData  # noqa: E501

class TestParticipantDashboardTransmissionRightsAndNominationsGraphData(unittest.TestCase):
    """ParticipantDashboardTransmissionRightsAndNominationsGraphData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ParticipantDashboardTransmissionRightsAndNominationsGraphData:
        """Test ParticipantDashboardTransmissionRightsAndNominationsGraphData
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ParticipantDashboardTransmissionRightsAndNominationsGraphData`
        """
        model = ParticipantDashboardTransmissionRightsAndNominationsGraphData()  # noqa: E501
        if include_optional:
            return ParticipantDashboardTransmissionRightsAndNominationsGraphData(
                mtus = [
                    empire_platform_api_public_client.models.participant_dashboard_transmission_rights_and_nominations_graph_data_mtus.ParticipantDashboardTransmissionRightsAndNominationsGraphData_mtus(
                        mtu = '2022-01-04T10:00Z', 
                        values = [
                            empire_platform_api_public_client.models.participant_dashboard_transmission_rights_and_nominations_graph_data_mtus_values.ParticipantDashboardTransmissionRightsAndNominationsGraphData_mtus_values(
                                direction = 'GB_NL', 
                                allocated_trs = 56, 
                                nominated_capacity = 56, )
                            ], )
                    ]
            )
        else:
            return ParticipantDashboardTransmissionRightsAndNominationsGraphData(
                mtus = [
                    empire_platform_api_public_client.models.participant_dashboard_transmission_rights_and_nominations_graph_data_mtus.ParticipantDashboardTransmissionRightsAndNominationsGraphData_mtus(
                        mtu = '2022-01-04T10:00Z', 
                        values = [
                            empire_platform_api_public_client.models.participant_dashboard_transmission_rights_and_nominations_graph_data_mtus_values.ParticipantDashboardTransmissionRightsAndNominationsGraphData_mtus_values(
                                direction = 'GB_NL', 
                                allocated_trs = 56, 
                                nominated_capacity = 56, )
                            ], )
                    ],
        )
        """

    def testParticipantDashboardTransmissionRightsAndNominationsGraphData(self):
        """Test ParticipantDashboardTransmissionRightsAndNominationsGraphData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 5.0.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from empire_platform_api_public_client.models.submit_day_ahead_or_intra_day_bids_request import SubmitDayAheadOrIntraDayBidsRequest  # noqa: E501

class TestSubmitDayAheadOrIntraDayBidsRequest(unittest.TestCase):
    """SubmitDayAheadOrIntraDayBidsRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SubmitDayAheadOrIntraDayBidsRequest:
        """Test SubmitDayAheadOrIntraDayBidsRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SubmitDayAheadOrIntraDayBidsRequest`
        """
        model = SubmitDayAheadOrIntraDayBidsRequest()  # noqa: E501
        if include_optional:
            return SubmitDayAheadOrIntraDayBidsRequest(
                bid_groups = [
                    empire_platform_api_public_client.models.submit_day_ahead_or_intra_day_bids_request_bid_groups.SubmitDayAheadOrIntraDayBidsRequest_bidGroups(
                        id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                        bid_tag = '', 
                        bids = [
                            empire_platform_api_public_client.models.submit_day_ahead_or_intra_day_bids_request_bid_groups_bids.SubmitDayAheadOrIntraDayBidsRequest_bidGroups_bids(
                                mtu = '2022-01-04T10:00Z', 
                                value = empire_platform_api_public_client.models.bid_value.BidValue(
                                    price = 1.337, 
                                    capacity = 56, ), )
                            ], )
                    ]
            )
        else:
            return SubmitDayAheadOrIntraDayBidsRequest(
                bid_groups = [
                    empire_platform_api_public_client.models.submit_day_ahead_or_intra_day_bids_request_bid_groups.SubmitDayAheadOrIntraDayBidsRequest_bidGroups(
                        id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                        bid_tag = '', 
                        bids = [
                            empire_platform_api_public_client.models.submit_day_ahead_or_intra_day_bids_request_bid_groups_bids.SubmitDayAheadOrIntraDayBidsRequest_bidGroups_bids(
                                mtu = '2022-01-04T10:00Z', 
                                value = empire_platform_api_public_client.models.bid_value.BidValue(
                                    price = 1.337, 
                                    capacity = 56, ), )
                            ], )
                    ],
        )
        """

    def testSubmitDayAheadOrIntraDayBidsRequest(self):
        """Test SubmitDayAheadOrIntraDayBidsRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 5.0.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel, Field
from empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_bid_group_result_bids_bid import DayAheadOrIntraDayAuctionBidGroupResultBidsBid

class DayAheadOrIntraDayAuctionBidGroupResultBids(BaseModel):
    """
    DayAheadOrIntraDayAuctionBidGroupResultBids
    """
    mtu: datetime = Field(..., description="The first moment (inclusive) of an MTU period  - theoretically can be sent and received with any zone offset (until it marks the desired **absolute MTU start point** on the timeline) - in practice it is advised to transfer it in UTC timezone (with Z offset, \"Zulu time\") - ISO 8601 compliant string in `yyyy-mm-ddThh:mm:ss.SSSZ` format - only with `XX:00:00`, `XX:15:00`, `XX:30:00` and `XX:45:00` time parts are valid values (depending on MTU size) ")
    bid: Optional[DayAheadOrIntraDayAuctionBidGroupResultBidsBid] = None
    __properties = ["mtu", "bid"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> DayAheadOrIntraDayAuctionBidGroupResultBids:
        """Create an instance of DayAheadOrIntraDayAuctionBidGroupResultBids from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of bid
        if self.bid:
            _dict['bid'] = self.bid.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> DayAheadOrIntraDayAuctionBidGroupResultBids:
        """Create an instance of DayAheadOrIntraDayAuctionBidGroupResultBids from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return DayAheadOrIntraDayAuctionBidGroupResultBids.parse_obj(obj)

        _obj = DayAheadOrIntraDayAuctionBidGroupResultBids.parse_obj({
            "mtu": obj.get("mtu"),
            "bid": DayAheadOrIntraDayAuctionBidGroupResultBidsBid.from_dict(obj.get("bid")) if obj.get("bid") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 5.0.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from empire_platform_api_public_client.models.invoice_group import InvoiceGroup  # noqa: E501

class TestInvoiceGroup(unittest.TestCase):
    """InvoiceGroup unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InvoiceGroup:
        """Test InvoiceGroup
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `InvoiceGroup`
        """
        model = InvoiceGroup()  # noqa: E501
        if include_optional:
            return InvoiceGroup(
                id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09',
                display_id = '',
                attachment = empire_platform_api_public_client.models.attachment.Attachment(
                    id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                    file_name = '', 
                    file_size = 0, 
                    mime_type = '', 
                    url = '', ),
                invoices = [
                    empire_platform_api_public_client.models.invoice.Invoice(
                        id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                        display_id = '', 
                        participant = empire_platform_api_public_client.models.invoice_participant_details.InvoiceParticipantDetails(
                            id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                            name = '', ), 
                        net_amount = 1.337, 
                        gross_amount = 1.337, 
                        due_date = 'Tue Jan 04 00:00:00 UTC 2022', 
                        status = 'DRAFT', 
                        last_status_change = '2022-01-04T00:00Z', 
                        attachment = empire_platform_api_public_client.models.attachment.Attachment(
                            id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                            file_name = '', 
                            file_size = 0, 
                            mime_type = '', 
                            url = '', ), )
                    ],
                net_amount = 1.337,
                gross_amount = 1.337,
                status = 'DRAFT',
                due_date = 'Tue Jan 04 00:00:00 UTC 2022',
                last_status_change = '2022-01-04T00:00Z',
                participant = empire_platform_api_public_client.models.invoice_participant_details.InvoiceParticipantDetails(
                    id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                    name = '', )
            )
        else:
            return InvoiceGroup(
                id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09',
                display_id = '',
                invoices = [
                    empire_platform_api_public_client.models.invoice.Invoice(
                        id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                        display_id = '', 
                        participant = empire_platform_api_public_client.models.invoice_participant_details.InvoiceParticipantDetails(
                            id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                            name = '', ), 
                        net_amount = 1.337, 
                        gross_amount = 1.337, 
                        due_date = 'Tue Jan 04 00:00:00 UTC 2022', 
                        status = 'DRAFT', 
                        last_status_change = '2022-01-04T00:00Z', 
                        attachment = empire_platform_api_public_client.models.attachment.Attachment(
                            id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                            file_name = '', 
                            file_size = 0, 
                            mime_type = '', 
                            url = '', ), )
                    ],
                net_amount = 1.337,
                gross_amount = 1.337,
                status = 'DRAFT',
                last_status_change = '2022-01-04T00:00Z',
                participant = empire_platform_api_public_client.models.invoice_participant_details.InvoiceParticipantDetails(
                    id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                    name = '', ),
        )
        """

    def testInvoiceGroup(self):
        """Test InvoiceGroup"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 5.0.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from empire_platform_api_public_client.models.aggregated_allocated_auction import AggregatedAllocatedAuction  # noqa: E501

class TestAggregatedAllocatedAuction(unittest.TestCase):
    """AggregatedAllocatedAuction unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AggregatedAllocatedAuction:
        """Test AggregatedAllocatedAuction
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AggregatedAllocatedAuction`
        """
        model = AggregatedAllocatedAuction()  # noqa: E501
        if include_optional:
            return AggregatedAllocatedAuction(
                timescale = 'LONG_TERM',
                auction_count = 0,
                product_type_count = 0,
                border_direction = 'GB_NL',
                delivery_period = empire_platform_api_public_client.models.mtu_period.MtuPeriod(
                    from_mtu_start = '2022-01-04T10:00Z', 
                    to_mtu_end = '2022-01-04T11:00Z', ),
                participant_requested_count = 0,
                participant_allocated_count = 0,
                offered_capacity = 56,
                total_requested_capacity = 56,
                total_allocated_capacity = 56,
                average_clearing_price = 1.337
            )
        else:
            return AggregatedAllocatedAuction(
                timescale = 'LONG_TERM',
                auction_count = 0,
                product_type_count = 0,
                border_direction = 'GB_NL',
                delivery_period = empire_platform_api_public_client.models.mtu_period.MtuPeriod(
                    from_mtu_start = '2022-01-04T10:00Z', 
                    to_mtu_end = '2022-01-04T11:00Z', ),
                participant_requested_count = 0,
                participant_allocated_count = 0,
                offered_capacity = 56,
                total_requested_capacity = 56,
                total_allocated_capacity = 56,
                average_clearing_price = 1.337,
        )
        """

    def testAggregatedAllocatedAuction(self):
        """Test AggregatedAllocatedAuction"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 5.0.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from empire_platform_api_public_client.models.participant_dashboard_interconnector_capacity_data_mtus_values import ParticipantDashboardInterconnectorCapacityDataMtusValues  # noqa: E501

class TestParticipantDashboardInterconnectorCapacityDataMtusValues(unittest.TestCase):
    """ParticipantDashboardInterconnectorCapacityDataMtusValues unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ParticipantDashboardInterconnectorCapacityDataMtusValues:
        """Test ParticipantDashboardInterconnectorCapacityDataMtusValues
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ParticipantDashboardInterconnectorCapacityDataMtusValues`
        """
        model = ParticipantDashboardInterconnectorCapacityDataMtusValues()  # noqa: E501
        if include_optional:
            return ParticipantDashboardInterconnectorCapacityDataMtusValues(
                direction = 'GB_NL',
                data = empire_platform_api_public_client.models.ntc_overview_mtu_data.NtcOverviewMtuData(
                    default_capacity = 56, 
                    effective_addition = 56, 
                    effective_reduction = 56, 
                    ntc = 56, )
            )
        else:
            return ParticipantDashboardInterconnectorCapacityDataMtusValues(
                direction = 'GB_NL',
                data = empire_platform_api_public_client.models.ntc_overview_mtu_data.NtcOverviewMtuData(
                    default_capacity = 56, 
                    effective_addition = 56, 
                    effective_reduction = 56, 
                    ntc = 56, ),
        )
        """

    def testParticipantDashboardInterconnectorCapacityDataMtusValues(self):
        """Test ParticipantDashboardInterconnectorCapacityDataMtusValues"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
